==> wmconfig-1.2.5.tar.bz2: wmconfig-1.2.5/twm.c <==
/*
 * Copyright (C) 2002
 *	Tommy Scheunemann <net@arrishq.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "wmconfig.h"
#include "prototypes.h"
#include "package.h"
#include <stdio.h>

/*
 Output function for twm, required by wmconfig.c
*/

void output_twm(struct group *root, char *use_term, int twm_type)
{
 struct item *item;
 if (root == (struct group *)NULL)
  return;

/* create entries for menus */

 if (twm_type == 2)
  printf("piemenu \"%s\" {\n", root->name, root->name);
 else
  printf("menu \"%s\"\n{\n \"%s\" f.title\n", root->name, root->name);

 if (twm_type == 3)
  printf(" \"Pin menu\" f.pin\n \"\" f.nop");
 
 item = root->items;
 
/* read the complete input data and create menus */

 while (item->type != 0) {
  if (item->type == ITEM_MENU) {
   struct group *tmp;
   tmp = (struct group *)item->data;

/* create entries for submenus */

   if (twm_type == 2)
    printf(" \"%s\" f.piemenu \"%s\"\n", tmp->name, tmp->name);
   else
    printf(" \"%s\" f.menu \"%s\"\n", tmp->name, tmp->name);
  }
  item++;
 }
 item = root->items;
 
/* this will read the input data and creates
 the application entries */

 while (item->type != 0) {
  if (item->type == ITEM_APP) {
   struct package *app;
   app = (struct package *)item->data;

   /* Check if we want to restart, quit, start another Wm */

   if (app->restart) {
    if (strncasecmp(app->restart, "restart", 7) == 0)
     printf(" \"%s\" f.restart\n", app->name);
    else if (strncasecmp(app->restart, "quit", 4) == 0)
     printf(" \"%s\" f.quit\n", app->name);
    else
     if (twm_type == 0)
      printf(" \"%s\" f.startwm \"%s\"\n", app->name, app->exec);

   /* ... or create a normal menu entry */     

   } else {
    if (app->name && app->exec && app->terminal)
     printf(" \"%s\" f.exec \"%s -e %s\"\n", app->name, use_term, app->exec);
    else
     printf (" \"%s\" f.exec \"%s\"\n", app->name, app->exec);
   }
  }
  item++;
 }

/* menu / submenu finished */

 printf("}\n\n");
 item = root->items;
 while (item->type != 0) {
  if (item->type == ITEM_MENU)
   output_twm(item->data, use_term, twm_type);
  item++;
 }
 return;
}

==> wmconfig-1.3.3.tar.bz2: wmconfig-1.3.3/twm.c <==
/*
 * Copyright (C) 2002
 *	Tommy Scheunemann <net@arrishq.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "wmconfig.h"
#include "prototypes.h"
#include "package.h"

#include <stdio.h>
#include <strings.h>

/*
 Output function for twm, required by wmconfig.c
*/

void output_twm(struct group *root,const char *use_term, const int twm_type)
{
 struct item *item;
 if (root == (struct group *)NULL)
  return;

/* create entries for menus */

 if (twm_type == 2)
  printf("piemenu \"%s\" {\n", root->name);
 else
  printf("menu \"%s\"\n{\n \"%s\" f.title\n", root->name, root->name);

 if (twm_type == 3)
  printf(" \"Pin menu\" f.pin\n \"\" f.nop");
 
 item = root->items;
 
/* read the complete input data and create menus */

 while (item->type != 0) {
  if (item->type == ITEM_MENU) {
   struct group *tmp;
   tmp = (struct group *)item->data;

/* create entries for submenus */

   if (twm_type == 2)
    printf(" \"%s\" f.piemenu \"%s\"\n", tmp->name, tmp->name);
   else
    printf(" \"%s\" f.menu \"%s\"\n", tmp->name, tmp->name);
  }
  item++;
 }
 item = root->items;
 
/* this will read the input data and creates
 the application entries */

 while (item->type != 0) {
  if (item->type == ITEM_APP) {
   struct package *app;
   app = (struct package *)item->data;

   /* Check if we want to restart, quit, start another Wm */

   if (app->restart) {
    if (strncasecmp(app->restart, "restart", 7) == 0)
     printf(" \"%s\" f.restart\n", app->name);
    else if (strncasecmp(app->restart, "quit", 4) == 0)
     printf(" \"%s\" f.quit\n", app->name);
    else
     if (twm_type == 0)
      printf(" \"%s\" f.startwm \"%s\"\n", app->name, app->exec);

   /* ... or create a normal menu entry */     

   } else {
    if (app->name && app->exec && app->terminal)
     printf(" \"%s\" f.exec \"%s -e %s\"\n", app->name, use_term, app->exec);
    else
     printf (" \"%s\" f.exec \"%s\"\n", app->name, app->exec);
   }
  }
  item++;
 }

/* menu / submenu finished */

 printf("}\n\n");
 item = root->items;
 while (item->type != 0) {
  if (item->type == ITEM_MENU)
   output_twm(item->data, use_term, twm_type);
  item++;
 }
 return;
}
